array - value
#############

array - array
-------------

.. doxygenfunction:: librapid::basic_ndarray::operator-(const basic_ndarray<B_T, B_A> &other) const
.. doxygenfunction:: librapid::basic_ndarray::operator-=(const basic_ndarray<B_T, B_A> &other)

array - scalar
--------------

.. doxygenfunction:: librapid::basic_ndarray::operator-(const B_T &other) const
.. doxygenfunction:: librapid::basic_ndarray::operator-=(const B_T &other)
